@@ -1,7 +1,7 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2010 Hiroyuki Yamamoto and the Claws Mail Team
- * Copyright (C) 2006-2010 Ricardo Mones
+ * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail Team
+ * Copyright (C) 2006-2011 Ricardo Mones
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,10 +33,16 @@
 #include "alertpanel.h"
 #include "gettext.h"
 
+struct _AttachWarnerMention {
+	int line;
+	gchar *context;
+};
+
+typedef struct _AttachWarnerMention AttachWarnerMention;
 
 MatcherProp *	new_matcherprop		  (void);
 gboolean 	matcherprop_string_match  (MatcherProp *mp, gchar *str);
-gboolean 	are_attachments_mentioned (Compose *compose);
+AttachWarnerMention *are_attachments_mentioned (Compose *compose);
 gboolean 	does_not_have_attachments (Compose *compose);
 
 gint 		plugin_init	  	  (gchar **error);
