@@ -83,8 +83,10 @@ static void *download_file_curl (void *data);
 static void download_file_cb(GtkWidget *widget, FancyViewer *viewer);
 #endif
 
-/*FIXME substitute webkitwebsettings.cpp functions with their API when available */
-gchar* webkit_web_view_get_selected_text(WebKitWebView* webView);
+#if !WEBKIT_CHECK_VERSION (1,5,1)
+gchar* webkit_web_view_get_selected_text(WebKitWebView* web_view);
+#endif
+
 /*------*/
 static GtkWidget *fancy_get_widget(MimeViewer *_viewer)
 {
@@ -139,7 +141,11 @@ static gboolean fancy_show_mimepart_real(MimeViewer *_viewer)
 		gchar *tmp = g_filename_to_uri(viewer->filename, NULL, NULL);
 		debug_print("zoom_level: %i\n", fancy_prefs.zoom_level);
 		webkit_web_view_set_zoom_level(viewer->view, (fancy_prefs.zoom_level / 100.0));
+#if WEBKIT_CHECK_VERSION(1,1,1)
+		webkit_web_view_load_uri(viewer->view, tmp);
+#else
 		webkit_web_view_open(viewer->view, tmp);
+#endif
 		g_free(tmp);
 	}
 	viewer->loading = FALSE;
@@ -243,6 +249,8 @@ static void fancy_print(MimeViewer *_viewer)
 
 	gtk_print_unix_dialog_set_manual_capabilities(print_dialog,
 												  GTK_PRINT_CAPABILITY_GENERATE_PS);
+	gtk_print_unix_dialog_set_manual_capabilities(print_dialog,
+												  GTK_PRINT_CAPABILITY_PREVIEW);
 
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_hide (dialog);
@@ -293,7 +301,19 @@ static gchar *fancy_get_selection (MimeViewer *_viewer)
 {
 	debug_print("fancy_get_selection\n");
 	FancyViewer *viewer = (FancyViewer *) _viewer;
+#if WEBKIT_CHECK_VERSION(1,5,1)
+	viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
+	viewer->window = webkit_dom_document_get_default_view (viewer->doc);
+	viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
+	if (viewer->selection == NULL)
+		return NULL;
+	viewer->range = webkit_dom_dom_selection_get_range_at(viewer->selection, 0, NULL);
+	if (viewer->range == NULL)
+		return NULL;
+	gchar *sel = webkit_dom_range_get_text (viewer->range);
+#else
 	gchar *sel = webkit_web_view_get_selected_text(viewer->view);
+#endif
 	if (!viewer->view || strlen(sel) == 0) {
 		g_free(sel);
 		return NULL;
@@ -312,12 +332,16 @@ static void fancy_clear_viewer(MimeViewer *_viewer)
 	viewer->override_prefs_scripts = FALSE;
 	viewer->override_prefs_plugins = FALSE;
 	viewer->override_prefs_java = FALSE;
+#if WEBKIT_CHECK_VERSION(1,1,1)
+	webkit_web_view_load_uri(viewer->view, "about:blank");
+#else
 	webkit_web_view_open(viewer->view, "about:blank");
+#endif
 	debug_print("fancy_clear_viewer\n");
 	fancy_prefs.zoom_level = webkit_web_view_get_zoom_level(viewer->view) * 100;
 	viewer->to_load = NULL;
 	vadj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(viewer->scrollwin));
-	vadj->value = 0.0;
+	gtk_adjustment_set_value(vadj, 0.0);
 	g_signal_emit_by_name(G_OBJECT(vadj), "value-changed", 0);
 }
 
@@ -686,9 +710,21 @@ static void search_the_web_cb(GtkWidget *widget, FancyViewer *viewer)
 	debug_print("Clicked on Search on Web\n");
 	if (webkit_web_view_has_selection(viewer->view)) {
 		gchar *search;
+#if WEBKIT_CHECK_VERSION(1,5,1)
+		viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
+		viewer->window = webkit_dom_document_get_default_view (viewer->doc);
+		viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
+		viewer->range = webkit_dom_dom_selection_get_range_at(viewer->selection, 0, NULL);
+		gchar *tmp = webkit_dom_range_get_text (viewer->range);
+#else
 		gchar *tmp = webkit_web_view_get_selected_text(viewer->view);
+#endif
 		search = g_strconcat(GOOGLE_SEARCH, tmp, NULL);
+#if WEBKIT_CHECK_VERSION(1,1,1)
+		webkit_web_view_load_uri(viewer->view, search);
+#else
 		webkit_web_view_open(viewer->view, search);
+#endif
 		g_free(search);
 		g_free(tmp);
 	}
@@ -896,7 +932,6 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
 static gboolean populate_popup_cb (WebKitWebView *view, GtkWidget *menu, 
 								   FancyViewer *viewer)
 {
-	/*FIXME hack..until webkit does not give the proper way to handle it*/
 	Plugin *plugin = plugin_get_loaded_by_name("RSSyl");
 	gtk_container_foreach(GTK_CONTAINER(menu), 
 						  (GtkCallback)viewer_menu_handler, 
@@ -941,7 +976,19 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
 	if (webkit_web_view_can_copy_clipboard(view)) {
 		GtkClipboard *wv_clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
 		const gchar *sel_text;
-		sel_text = (const gchar*)webkit_web_view_get_selected_text(view);
+#if WEBKIT_CHECK_VERSION(1,5,1)
+		viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
+		viewer->window = webkit_dom_document_get_default_view (viewer->doc);
+		viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
+		if (viewer->selection == NULL)
+			return NULL;
+		viewer->range = webkit_dom_dom_selection_get_range_at(viewer->selection, 0, NULL);
+		if (viewer->range == NULL)
+			return NULL;
+		sel_text = (const *gchar)webkit_dom_range_get_text (viewer->range);
+#else
+		sel_text = (const *gchar)webkit_web_view_get_selected_text(viewer->view);
+#endif
 		gtk_clipboard_set_text(wv_clipboard, sel_text, -1);
 	}
 	return FALSE;
