@@ -214,7 +214,7 @@ gint plugin_init(gchar **error)
   bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
   /* Version check */
-  if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,5,38),
+  if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,10,41),
 			   VERSION_NUMERIC, _("Notification"), error))
     return -1;
 
@@ -342,7 +342,7 @@ gint plugin_init(gchar **error)
     MainWindow *mainwin = mainwindow_get_mainwindow();
 
 		g_idle_add(trayicon_startup_idle,NULL);
-    if(mainwin && gtkut_widget_get_visible(GTK_WIDGET(mainwin->window)))
+    if(mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window)))
       main_window_hide(mainwin);
     main_set_show_at_startup(FALSE);
   }
