@@ -40,6 +40,10 @@
 #  include <libnotify/notify.h>
 #endif
 
+#ifndef NOTIFY_CHECK_VERSION
+# define NOTIFY_CHECK_VERSION(a,b,c) 0
+#endif
+
 typedef struct {
   gint count;
   gchar *msg_path;
@@ -339,7 +343,11 @@ static gboolean notification_libnotify_create(MsgInfo *msginfo,
     break;
   }
 
-  ppopup->notification = notify_notification_new(summary, utf8_str, NULL, NULL);
+  ppopup->notification = notify_notification_new(summary, utf8_str, NULL
+#if !NOTIFY_CHECK_VERSION(0, 7, 0)
+      , NULL
+#endif
+      );
   g_free(utf8_str);
   if(ppopup->notification == NULL) {
     debug_print("Notification Plugin: Failed to create a new "
