@@ -302,7 +302,7 @@ gboolean notification_trayicon_main_window_close(gpointer source, gpointer data)
       MainWindow *mainwin = mainwindow_get_mainwindow();
 
       *close_allowed = FALSE;
-      if(mainwin && gtkut_widget_get_visible(GTK_WIDGET(mainwin->window)))
+      if(mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window)))
 	main_window_hide(mainwin);
     }
   }
@@ -318,7 +318,7 @@ gboolean notification_trayicon_main_window_got_iconified(gpointer source,
     return FALSE;
 
   if(notify_config.trayicon_hide_when_iconified &&
-     mainwin && gtkut_widget_get_visible(GTK_WIDGET(mainwin->window))
+     mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window))
      && !gtk_window_get_skip_taskbar_hint(GTK_WINDOW(mainwin->window))) {
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), TRUE);
   }
