@@ -283,32 +283,45 @@ static void init_email_slist(void)
 /* check if given address is in given addressbook */
 static gboolean addr_in_addressbook(gchar *addr, gchar *bookname)
 {
-  GSList *walk;	
-
-  /* check if email_list exists */
-  if(email_slist == NULL) {
-    email_slist = g_new0(PerlPluginTimedSList,1);
-    email_slist->g_slist = NULL;
-    debug_print("email_slist created\n");
+  /* If no book is given, check the address completion list
+   * (there may be other addresses that are not in the address book,
+   * added by other plugins). */
+  if(bookname == NULL) {
+    gboolean found;
+    start_address_completion();
+    found = (complete_matches_found(addr) > 0);
+    end_address_completion();
+    return found;
   }
+  else {
+    GSList *walk;
 
-  if(update_PerlPluginTimedSList(email_slist))
-    init_email_slist();
+    /* check if email_list exists */
+    if(email_slist == NULL) {
+      email_slist = g_new0(PerlPluginTimedSList,1);
+      email_slist->g_slist = NULL;
+      debug_print("email_slist created\n");
+    }
 
-  walk = email_slist->g_slist;
-  for(; walk != NULL; walk = g_slist_next(walk)) {
-    PerlPluginEmailEntry *ee = (PerlPluginEmailEntry *) walk->data;
-    gchar *a = g_utf8_casefold(ee->address, -1);
-    gchar *b = g_utf8_casefold(addr, -1);
-    if((!g_utf8_collate(a,b)) &&
-       ((bookname == NULL) || (!strcmp(ee->bookname,bookname)))) {
+    if(update_PerlPluginTimedSList(email_slist))
+      init_email_slist();
+
+    walk = email_slist->g_slist;
+    for(; walk != NULL; walk = g_slist_next(walk)) {
+      PerlPluginEmailEntry *ee = (PerlPluginEmailEntry *) walk->data;
+      gchar *a = g_utf8_casefold(ee->address, -1);
+      gchar *b = g_utf8_casefold(addr, -1);
+      if((!g_utf8_collate(a,b)) &&
+         ((bookname == NULL) || (!strcmp(ee->bookname,bookname)))) {
+        g_free(a);
+        g_free(b);
+        return TRUE;
+      }
       g_free(a);
       g_free(b);
-      return TRUE;
     }
-    g_free(a);
-    g_free(b);
   }
+
   return FALSE;
 }
 
