@@ -68,7 +68,7 @@ gint rssyl_parse_rdf(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				/* Title */
 				if( !xmlStrcmp(n->name, "title") ) {
 					content = xmlNodeGetContent(n);
-					fitem->title = rssyl_format_string(g_strdup(content), TRUE, TRUE);
+					fitem->title = rssyl_format_string(content, TRUE, TRUE);
 					xmlFree(content);
 					debug_print("RSSyl: XML - RDF title is '%s'\n", fitem->title);
 				}
@@ -76,7 +76,7 @@ gint rssyl_parse_rdf(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				/* Text */
 				if( !xmlStrcmp(n->name, "description") ) {
 					content = xmlNodeGetContent(n);
-					fitem->text = rssyl_format_string(g_strdup(content), FALSE, FALSE);
+					fitem->text = rssyl_format_string(content, FALSE, FALSE);
 					xmlFree(content);
 					debug_print("RSSyl: XML - got RDF text\n");
 				}
@@ -84,7 +84,7 @@ gint rssyl_parse_rdf(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				/* URL */
 				if( !xmlStrcmp(n->name, "link") ) {
 					content = xmlNodeGetContent(n);
-					fitem->link = rssyl_format_string(g_strdup(content), FALSE, TRUE);
+					fitem->link = rssyl_format_string(content, FALSE, TRUE);
 					xmlFree(content);
 					debug_print("RSSyl: XML - RDF link is '%s'\n", fitem->link);
 				}
@@ -112,7 +112,7 @@ gint rssyl_parse_rdf(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				/* Author */
 				if( !xmlStrcmp(n->name, "creator") ) {
 					content = xmlNodeGetContent(n);
-					fitem->author = rssyl_format_string(g_strdup(content), TRUE, TRUE);
+					fitem->author = rssyl_format_string(content, TRUE, TRUE);
 					xmlFree(content);
 					debug_print("RSSyl: XML - RDF author is '%s'\n", fitem->author);
 				}
@@ -204,7 +204,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			/* Title */
 			if( !xmlStrcmp(n->name, "title") ) {
 				content = xmlNodeGetContent(n);
-				fitem->title = rssyl_format_string(g_strdup(content), TRUE, TRUE);
+				fitem->title = rssyl_format_string(content, TRUE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - item title: '%s'\n", fitem->title);
 			}
@@ -214,7 +214,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				if( (fitem->text == NULL) && (got_encoded == FALSE) ) {
 					content = xmlNodeGetContent(n);
 					debug_print("RSSyl: XML - item text (description) caught\n");
-					fitem->text = rssyl_format_string(g_strdup(content), FALSE, FALSE);
+					fitem->text = rssyl_format_string(content, FALSE, FALSE);
 					xmlFree(content);
 				}
 			}
@@ -226,7 +226,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 					g_free(fitem->text); /* free "description" */
 					
 				content = xmlNodeGetContent(n);
-				fitem->text = rssyl_format_string(g_strdup(content), FALSE, FALSE);
+				fitem->text = rssyl_format_string(content, FALSE, FALSE);
 				xmlFree(content);
 				got_encoded = TRUE;
 			}
@@ -234,7 +234,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			/* URL link to the original post */
 			if( !xmlStrcmp(n->name, "link") ) {
 				content = xmlNodeGetContent(n);
-				fitem->link = rssyl_format_string(g_strdup(content), FALSE, TRUE);
+				fitem->link = rssyl_format_string(content, FALSE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - item link: '%s'\n", fitem->link);
 			}
@@ -246,10 +246,10 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				fitem->id_is_permalink = FALSE;
 				if( !tmp || xmlStrcmp(tmp, "false") )	/* permalink? */
 					fitem->id_is_permalink = TRUE;
-				fitem->id = rssyl_format_string(g_strdup(content), FALSE, TRUE);
+				fitem->id = rssyl_format_string(content, FALSE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - item guid: '%s'\n", fitem->id);
-				g_free(tmp);
+				xmlFree(tmp);
 			}
 
 			/* Date - rfc822 format */
@@ -273,7 +273,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			/* Author */
 			if( !xmlStrcmp(n->name, "author") ) {
 				content = xmlNodeGetContent(n);
-				fitem->author = rssyl_format_string(g_strdup(content), TRUE, TRUE);
+				fitem->author = rssyl_format_string(content, TRUE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - item author: '%s'\n", fitem->author);
 				got_author = TRUE;
@@ -282,7 +282,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			if( !xmlStrcmp(n->name, "creator")
 					&& !xmlStrcmp(n->ns->prefix, "dc") && !got_author) {
 				content = xmlNodeGetContent(n);
-				fitem->author = rssyl_format_string(g_strdup(content), TRUE, TRUE);
+				fitem->author = rssyl_format_string(content, TRUE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - item author (creator): '%s'\n", fitem->author);
 			}
@@ -293,6 +293,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				media_url = xmlGetProp(n, "url");
 				media_type = xmlGetProp(n, "type");
 				media_size = (tmp ? atoi(tmp) : 0);
+				xmlFree(tmp);
 
 				if( media_url != NULL &&
 						media_type != NULL &&
@@ -314,7 +315,7 @@ gint rssyl_parse_rss(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			/* Comments */
 			if( !xmlStrcmp(n->name, "commentRSS") || !xmlStrcmp(n->name, "commentRss") ) {
 				content = xmlNodeGetContent(n);
-				fitem->comments_link = rssyl_format_string(g_strdup(content), FALSE, TRUE);
+				fitem->comments_link = rssyl_format_string(content, FALSE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - comments_link: '%s'\n", fitem->comments_link);
 			}
@@ -382,7 +383,7 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			/* Title */
 			if( !xmlStrcmp(n->name, "title") ) {
 				content = xmlNodeGetContent(n);
-				fitem->title = rssyl_format_string(g_strdup(content), TRUE, TRUE);
+				fitem->title = rssyl_format_string(content, TRUE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - Atom item title: '%s'\n", fitem->title);
 			}
@@ -399,15 +400,16 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			if( !xmlStrcmp(n->name, "summary") && !got_content ) {
 				content = xmlNodeGetContent(n);
 				debug_print("RSSyl: XML - Atom item text (summary) caught\n");
-				fitem->text = rssyl_format_string(g_strdup(content), FALSE, FALSE);
+				fitem->text = rssyl_format_string(content, FALSE, FALSE);
 				xmlFree(content);
 			}
 
 			if( !xmlStrcmp(n->name, "content") ) {
+				gchar *tmp = xmlGetProp(n, "type");
 				debug_print("RSSyl: XML - Atom item text (content) caught\n");
 				if (fitem->text)
 					g_free(fitem->text);
-				if( !xmlStrcmp(xmlGetProp(n, "type"), "xhtml") ) {
+				if( !xmlStrcmp(tmp, "xhtml")) {
 					for( h = n->children; h; h = h->next ) {
 						if( !xmlStrcmp(h->name, "div") ) {
 							buf = xmlBufferCreate();
@@ -418,14 +420,14 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 					}
 				} else
 					content = xmlNodeGetContent(n);
-				fitem->text = rssyl_format_string(g_strdup(content), FALSE, FALSE);
-				g_free(content);
+				xmlFree(tmp);
+				fitem->text = rssyl_format_string(content, FALSE, FALSE);
+				xmlFree(content);
 				got_content = TRUE;
 			}
 
 			/* link */
 			if( !xmlStrcmp(n->name, "link") ) {
-
 				link_type = xmlGetProp(n, "type");
 				link_rel = xmlGetProp(n, "rel");
 				link_href = xmlGetProp(n, "href");
@@ -436,6 +438,8 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 				if( !link_rel || (link_rel && !xmlStrcmp(link_rel, "alternate")) ) {
 					fitem->link = link_href;
 					debug_print("RSSyl: XML - Atom item link: '%s'\n", fitem->link);
+					xmlFree(link_type);
+					xmlFree(link_rel);
 				} else if( link_rel && !xmlStrcmp(link_rel, "enclosure") ) {
 					debug_print("RSSyl: XML - Atom item enclosure: '%s' (%ld) [%s]\n",
 							link_href, link_size, link_type);
@@ -444,6 +448,11 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 					media->type = link_type;
 					media->size = link_size;
 					fitem->media = media;
+					xmlFree(link_rel);
+				} else {
+					xmlFree(link_type);
+					xmlFree(link_rel);
+					xmlFree(link_href);
 				}
 			}
 
@@ -467,18 +476,23 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			if( !xmlStrcmp(n->name, "author") ) {
 				xmlNodePtr subnode;
 				gchar *name = NULL, *mail = NULL;
+				gchar *tmp;
 				for (subnode = n->children; subnode; subnode = subnode->next) {
+					content = xmlNodeGetContent(subnode);
 					if (!xmlStrcmp(subnode->name, "name") && !name)
-						name = g_strdup(xmlNodeGetContent(subnode));
+						name = g_strdup(content);
 					if (!xmlStrcmp(subnode->name, "email") && !mail)
-						mail = g_strdup(xmlNodeGetContent(subnode));
+						mail = g_strdup(content);
+					xmlFree(content);
 				}
-				fitem->author = rssyl_format_string(g_strdup_printf("%s%s%s%s%s",
+				tmp = g_strdup_printf("%s%s%s%s%s",
 							name ? name:"",
 							name && mail ? " <":(mail?"<":""),
 							mail ? mail:"",
 							mail ? ">":"",
-							!name && !mail ? "N/A":""), TRUE, TRUE);
+							!name && !mail ? "N/A":"");
+				fitem->author = rssyl_format_string(tmp, TRUE, TRUE);
+				g_free(tmp);
 				g_free(name);
 				g_free(mail);
 				debug_print("RSSyl: XML - Atom item author: '%s'\n", fitem->author);
@@ -487,7 +501,7 @@ gint rssyl_parse_atom(xmlDocPtr doc, RSSylFolderItem *ritem, gchar *parent)
 			/* Comments */
 			if( !xmlStrcmp(n->name, "commentRSS") || !xmlStrcmp(n->name, "commentRss")) {
 				content = xmlNodeGetContent(n);
-				fitem->comments_link = rssyl_format_string(g_strdup(content), FALSE, TRUE);
+				fitem->comments_link = rssyl_format_string(content, FALSE, TRUE);
 				xmlFree(content);
 				debug_print("RSSyl: XML - comments_link: '%s'\n", fitem->comments_link);
 			}
